//Mutexクレート
use std::sync::Mutex;
//サウンドクレート
use kira::{
  manager::{
    AudioManager, AudioManagerSettings,
    backend::cpal::CpalBackend,
  },
  sound::static_sound::{StaticSoundData, StaticSoundSettings},
};
//tauriクレート
use tauri::App;
//サウンド構造体
pub struct Sound {
  sound_manager: Mutex<AudioManager>,
  sound_data: Mutex<Vec<StaticSoundData>>,
}
//サウンド構造体のメソッド
impl Sound {
  //コンストラクタ
  pub fn new(
    app:&mut App,
    path:Vec<String>
  ) -> Self {
    let snd_manager = AudioManager::<CpalBackend>::new(
      AudioManagerSettings::default()
    ).expect("Error");
    let mut data = Vec::new();
    for p in path {
      let resource_path = app.path_resolver()
      .resolve_resource(p)
      .expect("failed to resolve resource");
      let d = StaticSoundData::from_file(
        resource_path,
        StaticSoundSettings::default()
      ).unwrap();
      data.push(d);
    }
    Sound {
      sound_manager: Mutex::new(snd_manager),
      sound_data: Mutex::new(data),
    }
  }
  //サウンド再生
  pub fn play(
    &self,
    index:usize
  ) {
    let mut snd_manager = self.sound_manager.lock().unwrap();
    let snd_data = self.sound_data.lock().unwrap();
    snd_manager.play(snd_data[index].clone()).expect("Error play");
  }
}
